@@ -539,12 +539,12 @@ mail_conv_view_new ()
 void
 mail_conv_view_activate (MailConvView *mcv, GtkWidget *tree, GtkWidget *folder_tree, GtkWidget *check_mail, GtkWidget *sort_by, gboolean act)
 {
-	 if (!folder_tree || !check_mail || !sort_by)
+	 if (!check_mail || !sort_by)
 		  return;
 	 //gtk_widget_hide (folder_tree);
 	 //g_signal_emit (mcv, signals[MESSAGE_SHOWN], 0);
-	 gtk_widget_set_sensitive (check_mail, act);
-	 gtk_widget_set_sensitive (sort_by, act);
+	 gtk_widget_set_sensitive (check_mail, TRUE);
+	 gtk_widget_set_sensitive (sort_by, FALSE);
 }
 
 static gboolean
