@@ -225,10 +225,10 @@ mfv_folder_name (CamelStore *store, char *name, char *uri)
 		name = _("Junk");
 
 	if (uri && strncmp (uri, "mbox", 4) == 0) {
-		new_name = g_strdup_printf ("%s %s '%s'", name, _("on"), _("On This Computer"));
+		new_name = g_strdup_printf ("%s %s '%s'", _(name), _("on"), _("On This Computer"));
 	} else {
 		char *tmpstr = camel_service_get_name((CamelService *)store, TRUE);
-		new_name = g_strdup_printf ("%s %s '%s'", name, _("on"), tmpstr);
+		new_name = g_strdup_printf ("%s %s '%s'", _(name), _("on"), tmpstr);
 		g_free(tmpstr);
 	}
 	return new_name;
