@@ -223,7 +223,8 @@ mmv_message_opened(CamelFolder *folder, const char *uid, CamelMimeMessage *msg,
 {
 	MailMessageView *shell = (MailMessageView *)data;
 	shell->priv->cancel = 0;
-#warning "indicate new mail"	
+#warning "indicate new mail"
+	gtk_widget_set_sensitive (shell->footer, TRUE);
 //	mail_indicate_new_mail (FALSE);
 	//gtk_widget_hide (shell->priv->table_headers);
 	//gtk_widget_show (shell->priv->html_headers);
@@ -1553,6 +1554,7 @@ mail_message_view_set_message (MailMessageView *mmview, CamelFolder *folder, con
 	gtk_widget_hide (mmview->pop_out);
 	gtk_box_pack_end ((GtkBox *)mmview->footer, mmview->pop_out, FALSE, FALSE, 12);
 
+	gtk_widget_set_sensitive (mmview->footer, FALSE);
 //	EXPOSE(discard, bgcolor);
 	/* Hide this one be default */
 	mmview->cbox = gtk_hbox_new (FALSE, 0);
